# AQIMON

A simple Air Quality Index monitor, designed to work on the Raspberry Pi with the SDS011 Nova PM Sensor.

## Installation

Requires [uhubctl](https://github.com/mvp/uhubctl) to be installed and on your PATH.

TODO: Instructions to pip install.